@@ -318,7 +318,7 @@ class ReturnsOperator(IndicatorOperator):
 # max min operators
 ###############
 
-class ForwardMaxPriceAndReturn(IndicatorOperator):
+class MaxPriceAndReturn(IndicatorOperator):
     @staticmethod
     def get_column_names():
         return ["Price-Max", "Return-Max"]
@@ -341,7 +341,7 @@ class ForwardMaxPriceAndReturn(IndicatorOperator):
         return data
 
 
-class ForwardMinPriceAndReturn(IndicatorOperator):
+class MinPriceAndReturn(IndicatorOperator):
     @staticmethod
     def get_column_names():
         return ["Price-Min", "Return-Min"]
