@@ -42,7 +42,7 @@ def _get_target_settings(setting_key: str):
 def _get_feature_settings(setting_key: str):
     ind = IndicatorFeatureSettings(**{
         'win_lens': [70],
-        'feature_names': [ReturnsOperator.__name__]
+        'feature_names': [ReturnsOperator.__name__, MaxPriceAndReturn.__name__, MinPriceAndReturn.__name__]
     })
 
     settings = {"ind": ind}
@@ -53,7 +53,7 @@ def _get_lag_settings(setting_key: str):
     ind = IndicatorLagSettings(**{'feature_parameters':
         {
             'win_lens': [30],
-            'feature_names': [ReturnsOperator.__name__]
+            'feature_names': [ReturnsOperator.__name__, MaxPriceAndReturn.__name__, MinPriceAndReturn.__name__]
         },
         'lag_lens': [3]
     })
